import { Construct } from 'constructs';
export interface DeboredOptions {
    /**
     * The Kubernetes namespace where this app to be deployed.
     * @default 'default'
     */
    readonly namespace?: string;
    /**
     * The Docker image to use for this app.
     */
    readonly image: string;
    /**
     * Number of replicas.
     *
     * If `autoScale` is enabled, this will be used for `minReplicas` (while
     * `maxReplicas` is x10). Otherwise, this value will be used to specify the
     * exact number of replicas in the deployment.
     *
     * @default 1
     */
    readonly defaultReplicas?: number;
    /**
     * External port.
     * @default 80
     */
    readonly port?: number;
    /**
     * Internal port.
     * @default 8080
     */
    readonly containerPort?: number;
    /**
     * Whether use HPA or not.
     * @default false
     */
    readonly autoScale?: boolean;
    /**
     * The type of ingress.
     * @default IngressType.SERVICE_LOADBALANCER
     */
    readonly ingress?: IngressType;
    /**
     * Resources requests for the web app.
     * @default - Requests = { CPU = 200m, Mem = 256Mi }, Limits = { CPU = 400m, Mem = 512Mi }
     */
    readonly resources?: ResourceRequirements;
}
export declare enum IngressType {
    SERVICE_LOADBALANCER = 0,
    CLUSTER_IP = 1,
    NGINX_INGRESS = 2
}
export interface ResourceRequirements {
    /**
     * Maximum resources for the web app.
     * @default - CPU = 400m, Mem = 512Mi
     */
    readonly limits?: ResourceQuantity;
    /**
     * Required resources for the web app.
     * @default - CPU = 200m, Mem = 256Mi
     */
    readonly requests?: ResourceQuantity;
}
export interface ResourceQuantity {
    /**
     * @default - no limit
     */
    readonly cpu?: string;
    /**
     * @default - no limit
     */
    readonly memory?: string;
}
/**
 * DeboredApp class.
 */
export declare class DeboredApp extends Construct {
    constructor(scope: Construct, name: string, opts: DeboredOptions);
}
